@@ -1,6 +1,6 @@
 module Test.Framework.Runners.Console (
         defaultMain, defaultMainWithArgs, defaultMainWithOpts,
-        interpretArgs, interpretArgsOrExit
+        optionsDescription, interpretArgs, interpretArgsOrExit
     ) where
 
 import Test.Framework.Core
@@ -14,6 +14,7 @@ import qualified Test.Framework.Runners.XML as XML
 import Test.Framework.Seed
 import Test.Framework.Utilities
 
+import Control.Monad (when)
 import System.Console.GetOpt
 import System.Environment
 import System.Exit
@@ -64,6 +65,9 @@ optionsDescription = [
         Option [] ["no-timeout"]
             (NoArg (mempty { ropt_test_options = Just (mempty { topt_timeout = Just Nothing }) }))
             "specifies that tests should be run without a timeout, by default",
+        Option ['l'] ["list-tests"]
+            (NoArg (mempty { ropt_list_only = Just True }))
+            "list available tests but don't run any; useful to guide subsequent --select-tests",
         Option ['t'] ["select-tests"]
             (ReqArg (\t -> mempty { ropt_test_patterns = Just [read t] }) "TEST-PATTERN")
             "only tests that match at least one glob pattern given by an instance of this argument will be run",
@@ -127,6 +131,10 @@ defaultMainWithOpts :: [Test] -> RunnerOptions -> IO ()
 defaultMainWithOpts tests ropts = do
     let ropts' = completeRunnerOptions ropts
     
+    when (unK$ ropt_list_only ropts') $ do 
+      putStr $ listTests tests
+      exitSuccess
+    
     -- Get a lazy list of the test results, as executed in parallel
     running_tests <- runTests ropts' tests
 
@@ -149,6 +157,18 @@ defaultMainWithOpts tests ropts = do
                then ExitSuccess
                else ExitFailure 1
 
+-- | Print out a list of available tests.
+listTests :: [Test] -> String
+listTests tests = "\ntest-framework: All available tests:\n"++
+                  "====================================\n"++ 
+                  concat (map (++"\n") (concatMap (showTest "") tests))
+  where 
+    showTest :: String -> Test -> [String]
+    showTest path (Test name _testlike)    = ["  "++path ++ name]
+    showTest path (TestGroup name tests)   = concatMap (showTest (path++":"++name)) tests
+    showTest path (PlusTestOptions _ test) = showTest path test
+    showTest path (BuildTestBracketed _)   = ["  "++path ++ "<created at runtime>"]
+
 
 completeRunnerOptions :: RunnerOptions -> CompleteRunnerOptions
 completeRunnerOptions ro = RunnerOptions {
@@ -158,5 +178,6 @@ completeRunnerOptions ro = RunnerOptions {
             ropt_xml_output = K $ ropt_xml_output ro `orElse` Nothing,
             ropt_xml_nested = K $ ropt_xml_nested ro `orElse` False,
             ropt_color_mode = K $ ropt_color_mode ro `orElse` ColorAuto,
-            ropt_hide_successes = K $ ropt_hide_successes ro `orElse` False
+            ropt_hide_successes = K $ ropt_hide_successes ro `orElse` False,
+            ropt_list_only      = K $ ropt_list_only      ro `orElse` False
         }
